//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/DataItemUtils.cpp
//! @brief     Implements namespace DataItemUtils
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Models/DataItemUtils.h"
#include "GUI/Models/IntensityDataItem.h"
#include "GUI/Models/JobItem.h"
#include "GUI/Models/RealDataItem.h"
#include "GUI/Models/SpecularDataItem.h"

namespace {
template <class DataItemType> DataItemType* dataItem(SessionItem* parent)
{
    ASSERT(parent && "Assertion failed in GUI::Model::DataItemUtils::dataItem: nullptr passed.");

    if (parent->modelType() == JobItem::M_TYPE)
        return dynamic_cast<DataItemType*>(dynamic_cast<JobItem*>(parent)->dataItem());
    if (auto real_data = dynamic_cast<RealDataItem*>(parent))
        return dynamic_cast<DataItemType*>(real_data->dataItem());
    if (auto self = dynamic_cast<DataItemType*>(parent))
        return self;
    ASSERT(0);
}
} // namespace

IntensityDataItem* GUI::Model::DataItemUtils::intensityDataItem(SessionItem* parent)
{
    return dataItem<IntensityDataItem>(parent);
}

SpecularDataItem* GUI::Model::DataItemUtils::specularDataItem(SessionItem* parent)
{
    return dataItem<SpecularDataItem>(parent);
}
