//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Models/Unit.cpp
//! @brief     Implements class Unit
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Models/Unit.h"
#include "Base/Const/Units.h"
#include "Base/Utils/Assert.h"

double convert(double d, Unit from, Unit to)
{
    if (from == Unit::undefined || to == Unit::undefined || from == to)
        return d;

    if (from == Unit::angstrom && to == Unit::nanometer)
        return d / 10.0;

    if (from == Unit::nanometer && to == Unit::angstrom)
        return d * 10.0;

    if (from == Unit::angstromPower2 && to == Unit::nanometerPower2)
        return d / 100.0;

    if (from == Unit::nanometerPower2 && to == Unit::angstromPower2)
        return d * 100.0;

    if (from == Unit::angstromPowerMinus2 && to == Unit::nanometerPowerMinus2)
        return d * 100.0;

    if (from == Unit::nanometerPowerMinus2 && to == Unit::angstromPowerMinus2)
        return d / 100.0;

    if (from == Unit::radiant && to == Unit::degree)
        return Units::rad2deg(d);

    if (from == Unit::degree && to == Unit::radiant)
        return Units::deg2rad(d);

    ASSERT(false); // no conversion implemented
    return d;
}
